@@ -358,6 +358,7 @@ gail_widget_ref_state_set (AtkObject *accessible)
       if (GTK_WIDGET_IS_SENSITIVE (widget))
         {
           atk_state_set_add_state (state_set, ATK_STATE_SENSITIVE);
+          atk_state_set_add_state (state_set, ATK_STATE_ENABLED);
         }
   
       if (GTK_WIDGET_CAN_FOCUS (widget))
@@ -400,7 +401,6 @@ gail_widget_ref_state_set (AtkObject *accessible)
         {
           atk_state_set_add_state (state_set, ATK_STATE_FOCUSED);
         }
-      atk_state_set_add_state (state_set, ATK_STATE_ENABLED);
     }
   return state_set;
 }
@@ -841,17 +841,17 @@ gail_widget_real_notify_gtk (GObject     *obj,
   AtkState state;
   gboolean value;
 
-  if (strcmp (pspec->name, "visible") == 0)
-    {
-      state = ATK_STATE_VISIBLE;
-      value = GTK_WIDGET_VISIBLE (widget);
-    }
-  else if (strcmp (pspec->name, "has-focus") == 0)
+  if (strcmp (pspec->name, "has-focus") == 0)
     /*
      * We use focus-in-event and focus-out-event signals to catch
      * focus changes so we ignore this.
      */
     return;
+  else if (strcmp (pspec->name, "visible") == 0)
+    {
+      state = ATK_STATE_VISIBLE;
+      value = GTK_WIDGET_VISIBLE (widget);
+    }
   else if (strcmp (pspec->name, "sensitive") == 0)
     {
       state = ATK_STATE_SENSITIVE;
